@@ -270,14 +270,17 @@ class Desktop(MethodsInterface):
         session = self.clVars.Get('cl_desktop_xsession')
         if session == 'xfce':
             logoutCommand = "/usr/bin/qdbus org.xfce.SessionManager " \
-                            "/org/xfce/SessionManager Logout False False"
+                            "/org/xfce/SessionManager " \
+                            "org.xfce.Session.Manager.Logout False False"
         elif session == 'kde':
             logoutCommand = "/usr/bin/kquitapp ksmserver"
         elif session == 'plasma':
-            logoutCommand = "/usr/bin/pkill -f ksmserver"
+            logoutCommand = "/usr/bin/qdbus org.kde.ksmserver /KSMServer " \
+                            "org.kde.KSMServerInterface.logout 0 0 0"
         elif session in ('gnome', 'mate', 'cinnamon-session'):
             logoutCommand = "/usr/bin/qdbus org.gnome.SessionManager " \
-                            "/org/gnome/SessionManager Logout 1"
+                            "/org/gnome/SessionManager " \
+                            "org.gnome.SessionManager.Logout 1"
         elif session == 'lxqt':
             logoutCommand = "/usr/bin/qdbus org.lxqt.session " \
                             "/LXQtSession org.lxqt.session.logout"
